OC.L10N.register(
    "files",
    {
    "File could not be found" : "Il file non può essere trovato",
    "Move or copy" : "Sposta o copia",
    "Download" : "Scarica",
    "Delete" : "Elimina",
    "Tags" : "Etichette",
    "Show list view" : "Mostra la vista elenco",
    "Show grid view" : "Mostra la visualizzazione griglia",
    "Home" : "Home",
    "Close" : "Chiudi",
    "Could not create folder \"{dir}\"" : "Impossibile creare la cartella \"{dir}\"",
    "This will stop your current uploads." : "Questo fermerà i caricamenti attuali.",
    "Upload cancelled." : "Caricamento annullato.",
    "Processing files …" : "Elaborazione file in corso…",
    "…" : "…",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Impossibile caricare {filename} poiché è una cartella oppure ha una dimensione di 0 byte",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Spazio insufficiente, stai caricando {size1}, ma è rimasto solo {size2}",
    "Target folder \"{dir}\" does not exist any more" : "La cartella di destinazione \"{dir}\" non esiste più",
    "Not enough free space" : "Spazio libero insufficiente",
    "An unknown error has occurred" : "Si è verificato un errore sconosciuto",
    "File could not be uploaded" : "Il file non può essere caricato",
    "Uploading …" : "Caricamento in corso...",
    "{remainingTime} ({currentNumber}/{total})" : "{remainingTime} ({currentNumber}/{total})",
    "Uploading … ({currentNumber}/{total})" : "Caricamento … ({currentNumber}/{total})",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} di {totalSize} ({bitrate})",
    "Uploading that item is not supported" : "Il caricamento di tale elemento non è supportato",
    "Target folder does not exist any more" : "La cartella di destinazione non esiste più",
    "Operation is blocked by access control" : "L'operazione è bloccata dal controllo di accesso",
    "Error when assembling chunks, status code {status}" : "Errore durante l'assemblaggio dei blocchi, codice di stato {status}",
    "Actions" : "Azioni",
    "Rename" : "Rinomina",
    "Move" : "Sposta",
    "Copy" : "Copia",
    "Choose target folder" : "Scegli la cartella di destinazione",
    "Set reminder" : "Imposta promemoria",
    "Edit locally" : "Modifica localmente",
    "Open" : "Apri",
    "Could not load info for file \"{file}\"" : "Impossibile caricare le informazioni per il file \"{file}\"",
    "Files" : "File",
    "Details" : "Dettagli",
    "Please select tag(s) to add to the selection" : "Seleziona un'etichetta(e) da aggiungere alla selezione",
    "Apply tag(s) to selection" : "Applica etichetta(e) alla selezione",
    "Select directory \"{dirName}\"" : "Seleziona cartella \"{dirName}\"",
    "Select file \"{fileName}\"" : "Seleziona file \"{fileName}\"",
    "Pending" : "In corso",
    "Unable to determine date" : "Impossibile determinare la data",
    "This operation is forbidden" : "Questa operazione è vietata",
    "This directory is unavailable, please check the logs or contact the administrator" : "Questa cartella non è disponibile, controlla i log o contatta l'amministratore",
    "Storage is temporarily not available" : "L'archiviazione è temporaneamente non disponibile",
    "Could not move \"{file}\", target exists" : "Impossibile spostare \"{file}\", la destinazione esiste già",
    "Could not move \"{file}\"" : "Impossibile spostare \"{file}\"",
    "copy" : "copia",
    "Could not copy \"{file}\", target exists" : "Impossibile copiare \"{file}\", la destinazione esiste già",
    "Could not copy \"{file}\"" : "Impossibile copiare \"{file}\"",
    "Copied {origin} inside {destination}" : "Copiato {origin} in {destination}",
    "Copied {origin} and {nbfiles} other files inside {destination}" : "Copiati {origin} e {nbfiles} altri file in {destination}",
    "Failed to redirect to client" : "Reindirizzamento al client non riuscito",
    "{newName} already exists" : "{newName} esiste già",
    "Could not rename \"{fileName}\", it does not exist any more" : "Impossibile rinominare \"{fileName}\", non esiste più",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Il nome \"{targetName}\" è attualmente in uso nella cartella \"{dir}\". Scegli un nome diverso.",
    "Could not rename \"{fileName}\"" : "Impossibile rinominare \"{fileName}\"",
    "Could not create file \"{file}\"" : "Impossibile creare il file \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "Impossibile creare il file \"{file}\" poiché esiste già",
    "Could not create folder \"{dir}\" because it already exists" : "Impossibile creare la cartella \"{dir}\" poiché esiste già",
    "Could not fetch file details \"{file}\"" : "Impossibile recuperare i dettagli del file \"{file}\"",
    "Error deleting file \"{fileName}\"." : "Errore durante l'eliminazione del file \"{fileName}\".",
    "No search results in other folders for {tag}{filter}{endtag}" : "Nessun risultato di ricerca nelle altre cartelle per {tag}{filter}{endtag}",
    "Enter more than two characters to search in other folders" : "Digita più di due caratteri per cercare in altre cartelle",
    "Name" : "Nome",
    "Size" : "Dimensione",
    "Modified" : "Modificato",
    "_%n folder_::_%n folders_" : ["%n cartella","%n cartelle","%n cartelle"],
    "_%n file_::_%n files_" : ["%n file","%n file","%n file"],
    "{dirs} and {files}" : "{dirs} e {files}",
    "_including %n hidden_::_including %n hidden_" : ["incluso %n nascosto","inclusi %n nascosti","inclusi %n nascosti"],
    "You do not have permission to upload or create files here" : "Non disponi dei permessi per caricare o creare file qui",
    "_Uploading %n file_::_Uploading %n files_" : ["Caricamento di %n file in corso","Caricamento di %n file in corso","Caricamento di %n file in corso"],
    "New" : "Nuovo",
    "New file/folder menu" : "Nuovo menu file/cartella",
    "Select file range" : "Seleziona intervallo di file",
    "{used}%" : "{used}%",
    "{used} of {quota} used" : "{used} di {quota} utilizzati",
    "{used} used" : "{used} utilizzati",
    "\"{name}\" is an invalid file name." : "\"{name}\" non è un nome file valido.",
    "File name cannot be empty." : "Il nome del file non può essere vuoto.",
    "\"/\" is not allowed inside a file name." : "\"/\" non è consentito nel nome di un file.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" non è un tipo di file valido",
    "Storage of {owner} is full, files cannot be updated or synced anymore!" : "Lo spazio di archiviazione di {owner} è pieno, i file non possono essere più aggiornati o sincronizzati!",
    "Group folder \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "La cartella di gruppo \"{mountPoint}\" è piena, i file non possono più essere aggiornati o sincronizzati!",
    "External storage \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "L'archiviazione esterna \"{mountPoint}\" è piena, i file non possono più essere caricati o sincronizzati!",
    "Your storage is full, files cannot be updated or synced anymore!" : "Lo spazio di archiviazione è pieno, i file non possono essere più caricati o sincronizzati!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)." : "Lo spazio di archiviazione di {owner} è quasi pieno ({usedSpacePercent}%).",
    "Group folder \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "La cartella di gruppo \"{mountPoint}\" è quasi piena ({usedSpacePercent}%).",
    "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "L'archiviazione esterna \"{mountPoint}\" è quasi piena ({usedSpacePercent}%).",
    "Your storage is almost full ({usedSpacePercent}%)." : "Lo spazio di archiviazione è quasi pieno ({usedSpacePercent}%).",
    "_matches \"{filter}\"_::_match \"{filter}\"_" : ["verifica \"{filter}\"","verificano \"{filter}\"","verificano \"{filter}\""],
    "View in folder" : "Visualizza nella cartella",
    "Path" : "Percorso",
    "_%n byte_::_%n bytes_" : ["%n byte","%n byte","%n byte"],
    "Favorited" : "Preferiti",
    "Favorite" : "Preferito",
    "New folder" : "Nuova cartella",
    "Create new folder" : "Crea una nuova cartella",
    "Upload file" : "Carica file",
    "Recent" : "Recenti",
    "Not favorited" : "Non preferito",
    "Remove from favorites" : "Rimuovi dai preferiti",
    "Add to favorites" : "Aggiungi ai preferiti",
    "An error occurred while trying to update the tags" : "Si è verificato un errore durante il tentativo di aggiornare le etichette",
    "Added to favorites" : "Aggiunto ai preferiti",
    "Removed from favorites" : "Rimosso dai preferiti",
    "You added {file} to your favorites" : "Hai aggiunto {file} ai tuoi preferiti",
    "You removed {file} from your favorites" : "Hai rimosso {file} dai tuoi preferiti",
    "Favorites" : "Preferiti",
    "File changes" : "Modifiche dei file",
    "Created by {user}" : "Creata da {user}",
    "Changed by {user}" : "Modificata da {user}",
    "Deleted by {user}" : "Eliminata da {user}",
    "Restored by {user}" : "Ripristinata da {user}",
    "Renamed by {user}" : "Rinominata da {user}",
    "Moved by {user}" : "Spostata da {user}",
    "You created {file}" : "Hai creato {file}",
    "You created an encrypted file in {file}" : "Hai creato un file cifrato in {file}",
    "{user} created {file}" : "{user} ha creato {file}",
    "{user} created an encrypted file in {file}" : "{user} ha creato un file cifrato in {file}",
    "{file} was created in a public folder" : "{file} è stato creato in una cartella pubblica",
    "You changed {file}" : "Hai modificato {file}",
    "You changed an encrypted file in {file}" : "Hai cambiato un file cifrato in {file}",
    "{user} changed {file}" : "{user} ha modificato {file}",
    "{user} changed an encrypted file in {file}" : "{user} ha cambiato un file cifrato in {file}",
    "You deleted {file}" : "Hai eliminato {file}",
    "You deleted an encrypted file in {file}" : "Hai eliminato un file cifrato in {file}",
    "{user} deleted {file}" : "{user} ha eliminato {file}",
    "{user} deleted an encrypted file in {file}" : "{user} ha eliminato un file cifrato in {file}",
    "You restored {file}" : "Hai ripristinato {file}",
    "{user} restored {file}" : "{user} ha ripristinato {file}",
    "You renamed {oldfile} (hidden) to {newfile} (hidden)" : "Hai rinominato {oldfile} (nascosto) in {newfile} (nascosto)",
    "You renamed {oldfile} (hidden) to {newfile}" : "Hai rinominato {oldfile} (nascosto) in {newfile}",
    "You renamed {oldfile} to {newfile} (hidden)" : "Hai rinominato {oldfile} in {newfile} (nascosto)",
    "You renamed {oldfile} to {newfile}" : "Hai rinominato {oldfile} in {newfile}",
    "{user} renamed {oldfile} (hidden) to {newfile} (hidden)" : "{user} ha rinominato {oldfile} (nascosto) in {newfile} (nascosto)",
    "{user} renamed {oldfile} (hidden) to {newfile}" : "{user} ha rinominato {oldfile} (nascosto) in {newfile}",
    "{user} renamed {oldfile} to {newfile} (hidden)" : "{user} ha rinominato {oldfile} in {newfile} (nascosto)",
    "{user} renamed {oldfile} to {newfile}" : "{user} ha rinominato {oldfile} in {newfile}",
    "You moved {oldfile} to {newfile}" : "Hai spostato {oldfile} in {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} ha spostato {oldfile} in {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "Un file  stato aggiunto o rimosso dai tuoi <strong>preferiti</strong>",
    "A file or folder has been <strong>changed</strong>" : "Un file o una cartella è stato <strong>modificato</strong>",
    "A favorite file or folder has been <strong>changed</strong>" : "Un file preferito o una cartella è stato <strong>modificato</strong>",
    "Upload (max. %s)" : "Carica (massimo %s)",
    "Accept" : "Accetta",
    "Reject" : "Rifiuta",
    "Incoming ownership transfer from {user}" : "Trasferimento di proprietà in ingresso da {user}",
    "Do you want to accept {path}?\n\nNote: The transfer process after accepting may take up to 1 hour." : "Vuoi accettare {path}?\n\nNota: il processo di trasferimento dopo l'accettazione potrebbe richiedere fino a un'ora.",
    "Ownership transfer failed" : "Trasferimento di proprietà non riuscito",
    "Your ownership transfer of {path} to {user} failed." : "Il tuo trasferimento di proprietà di {path} a {user} non è riuscito.",
    "The ownership transfer of {path} from {user} failed." : "Il trasferimento di proprietà di {path} da {user} non è riuscito.",
    "Ownership transfer done" : "Trasferimento di proprietà completato",
    "Your ownership transfer of {path} to {user} has completed." : "Il tuo trasferimento di proprietà di {path} a {user} è completato.",
    "The ownership transfer of {path} from {user} has completed." : "Il trasferimento di proprietà di {path} da {user} è completato.",
    "in %s" : "in %s",
    "File Management" : "Gestione dei file",
    "Current directory path" : "Percorso della cartella corrente",
    "Reload current directory" : "Ricarica la cartella corrente",
    "Go to the \"{dir}\" directory" : "Vai alla cartella \"{dir}\"",
    "Drag and drop files here to upload" : "Trascina i file qui per caricarli",
    "Your have used your space quota and cannot upload files anymore" : "Hai esaurito la tua quota di spazio e non puoi più caricare file",
    "You don’t have permission to upload or create files here" : "Qui non hai i permessi per caricare o creare file",
    "\"{displayName}\" action executed successfully" : "L'azione \"{displayName}\" è stata eseguita correttamente",
    "\"{displayName}\" action failed" : "L'azione \"{displayName}\" non è riuscita",
    "Rename file" : "Rinomina file",
    "File name" : "Nome file",
    "Folder name" : "Nome della cartella",
    "This node is unavailable" : "Questa nodo non è disponibile",
    "Download file {name}" : "Scarica il file {name}",
    "\"{name}\" is not an allowed filetype." : "\"{name}\" non è un tipo di file consentito.",
    "{newName} already exists." : "{newName} esiste già.",
    "\"{char}\" is not allowed inside a file name." : "\"{char}\" non è consentito in un nome di file.",
    "Name cannot be empty" : "Il nome non può essere vuoto",
    "Another entry with the same name already exists" : "Esiste già un'altra voce con lo stesso nome",
    "Renamed \"{oldName}\" to \"{newName}\"" : "Rinominato \"{oldName}\" in \"{newName}\"",
    "Could not rename \"{oldName}\", it does not exist any more" : "Impossibile rinominare \"{oldName}\", non esiste più",
    "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Il nome \"{newName}\" è attualmente in uso nella cartella \"{dir}\". Scegli un nome diverso.",
    "Could not rename \"{oldName}\"" : "Impossibile rinominare \"{oldName}\"",
    "Total rows summary" : "Riepilogo totale delle righe",
    "\"{displayName}\" failed on some elements " : "\"{displayName}\" non è riuscita su alcuni elementi",
    "\"{displayName}\" batch action executed successfully" : "L'azione batch \"{displayName}\" è stata eseguita correttamente",
    "List of files and folders." : "Lista di file e cartelle.",
    "Column headers with buttons are sortable." : "Le intestazioni di colonna con pulsanti sono ordinabili.",
    "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "Questa lista non è stata mostrata completamente per ragioni di prestazioni. I file verranno mostrati durante la navigazione della lista.",
    "File not found" : "File non trovato",
    "Storage informations" : "Informazioni di archiviazione",
    "{usedQuotaByte} used" : "{usedQuotaByte} usato",
    "{relative}% used" : "{relative}% usato",
    "Could not refresh storage stats" : "Impossibile aggiornare le statistiche di archiviazione",
    "Your storage is full, files can not be updated or synced anymore!" : "Lo spazio di archiviazione è pieno, i file non possono essere più aggiornati o sincronizzati!",
    "Create" : "Crea",
    "Transfer ownership of a file or folder" : " Trasferisci la proprietà di un file o di una cartella",
    "Choose file or folder to transfer" : "Scegli file o cartella da trasferire",
    "Change" : "Modifica",
    "New owner" : "Nuovo proprietario",
    "Choose a file or folder to transfer" : "Scegli file o cartella da trasferire",
    "Transfer" : "Trasferisci",
    "Transfer {path} to {userid}" : "Trasferisci {path} a {userid}",
    "Invalid path selected" : "Percorso selezionato non valido",
    "Unknown error" : "Errore sconosciuto",
    "Ownership transfer request sent" : "Richiesta di trasferimento della proprietà inviata",
    "Cannot transfer ownership of a file or folder you do not own" : "Impossibile trasferire la proprietà di un file o di una cartella di cui non sei proprietario",
    "Select file or folder to link to" : "Seleziona un file o una cartella da collegare",
    "Choose file" : "Scegli file",
    "Choose {file}" : "Scegli {file}",
    "Loading current folder" : "Sto caricando la cartella corrente",
    "No files in here" : "Qui non c'è alcun file",
    "Upload some content or sync with your devices!" : "Carica dei contenuti o sincronizza con i tuoi dispositivi!",
    "Go to the previous folder" : "Vai alla cartella precedente",
    "Go back" : "Indietro",
    "Share" : "Condividi",
    "Shared by link" : "Condivisi tramite collegamento",
    "Shared" : "Condiviso",
    "Switch to list view" : "Passa alla vista elenco",
    "Switch to grid view" : "Passa alla vista griglia",
    "Error during upload: {message}" : "Errore durante il caricamento: {message}",
    "Error during upload, status code {status}" : "Errore durante il caricamento, codice di stato {status}",
    "Unknown error during upload" : "Errore sconosciuto durante il caricamento",
    "Open the files app settings" : "Apri le impostazioni dell'applicazione File",
    "Files settings" : "Impostazioni File",
    "File cannot be accessed" : "Il file non possono essere acceduti",
    "Sort favorites first" : "Ordina prima i preferiti",
    "Show hidden files" : "Mostra i file nascosti",
    "Crop image previews" : "Ritaglia le anteprime delle immagini",
    "Enable the grid view" : "Attiva visuale a griglia",
    "Additional settings" : "Impostazioni aggiuntive",
    "WebDAV" : "WebDAV",
    "WebDAV URL" : "URL WebDAV",
    "Copy to clipboard" : "Copia negli appunti",
    "Use this address to access your Files via WebDAV" : "Usa questo indirizzo per accedere ai tuoi file con WebDAV",
    "If you have enabled 2FA, you must create and use a new app password by clicking here." : "Se hai abilitato il 2FA, devi creare ed usare una nuova password per l'applicazione facendo clic qui.",
    "Clipboard is not available" : "Appunti non disponibili",
    "WebDAV URL copied to clipboard" : "L'URL WebDAV è stato copiato negli appunti",
    "Unable to change the favourite state of the file" : "Impossibile cambiare lo stato di preferito del file",
    "Error while loading the file data" : "Errore durante il caricamento del file di dati",
    "Pick a template for {name}" : "Scegli un modello per {name}",
    "Create a new file with the selected template" : "Crea un nuovo file con il modello selezionato",
    "Creating file" : "Creazione del file",
    "Blank" : "Vuoto",
    "Unable to create new file from template" : "Impossibile creare un nuovo file dal modello",
    "Delete permanently" : "Elimina permanentemente",
    "Delete and unshare" : "Elimina e annulla la condivisione",
    "Cancel" : "Annulla",
    "Destination is not a folder" : "La destinazione non è una cartella",
    "This file/folder is already in that directory" : "Questo file/cartella è già in quella cartella",
    "You cannot move a file/folder onto itself or into a subfolder of itself" : "Non puoi spostare un file/cartella in se stesso o in una sottocartella di se stesso",
    "(copy)" : "(copia)",
    "(copy %n)" : "(copia %n)",
    "A file or folder with that name already exists in this folder" : "Esiste già un file o una cartella con quel nome in questa cartella",
    "The file does not exist anymore" : "Il file non esiste più",
    "Choose destination" : "Scegli la destinazione",
    "Copy to {target}" : "Copia in {target}",
    "Move to {target}" : "Sposta in {target}",
    "Cancelled move or copy operation" : "Operazione di spostamento o copia annullata",
    "Open folder {displayName}" : "Apri la cartella {displayName}",
    "Open in Files" : "Apri in File",
    "Open details" : "Apri i dettagli",
    "Could not copy {file}. {message}" : "Impossibile copiare {file}. {message}",
    "Could not move {file}. {message}" : "Impossibile spostare {file}. {message}",
    "Created new folder \"{name}\"" : "Crea una nuova cartella \"{name}\"",
    "Filename" : "Nome file",
    "Unable to initialize the templates directory" : "Impossibile inizializzare la cartella dei modelli",
    "Create new templates folder" : "Crea una nuova cartella dei modelli",
    "Templates" : "Modelli",
    "One of the dropped files could not be processed" : "Impossibile elaborare uno dei file eliminati",
    "Uploading \"{filename}\" failed" : "Caricamento di \"{filename}\" fallito",
    "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} cartella","{folderCount} cartelle","{folderCount} cartelle"],
    "_{fileCount} file_::_{fileCount} files_" : ["{fileCount} file","{fileCount} file","{fileCount} file"],
    "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 file e {folderCount} cartella","1 file e {folderCount} cartelle","1 file e {folderCount} cartelle"],
    "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["{fileCount} file e 1 cartella","{fileCount} file e 1 cartella","{fileCount} file e 1 cartella"],
    "{fileCount} files and {folderCount} folders" : "{fileCount} file e {folderCount} cartelle",
    "List of favorites files and folders." : "Lista di file e cartelle preferiti.",
    "No favorites yet" : "Nessun preferito ancora",
    "Files and folders you mark as favorite will show up here" : "I file e le cartelle che marchi come preferiti saranno mostrati qui",
    "All files" : "Tutti i file",
    "List of your files and folders." : "Lista dei tuoi file e cartelle.",
    "List of recently modified files and folders." : "Lista di file e cartelle modificati di recente.",
    "No recently modified files" : "Nessun file modificato di recente",
    "Files and folders you recently modified will show up here." : "I file e le cartelle che hai modificato di recente saranno mostrati qui.",
    "No entries found in this folder" : "Nessuna voce trovata in questa cartella",
    "Select all" : "Seleziona tutto",
    "Upload too large" : "Caricamento troppo grande",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "I file che stai provando a caricare superano la dimensione massima consentita su questo server.",
    "Text file" : "File di testo",
    "New text file.txt" : "Nuovo file di testo.txt",
    "Direct link was copied (only works for users who have access to this file/folder)" : "Il collegamento diretto è stato copiato (funziona solo per gli utenti che hanno accesso a questo file o cartella)",
    "Copy direct link (only works for users who have access to this file/folder)" : "Copia collegamento diretto (funziona solo per utenti che hanno accesso a questo file/cartella)",
    "You can only favorite a single file or folder at a time" : "Puoi aggiungere ai preferiti un singolo file o cartella alla volta",
    "\"remote user\"" : "\"utente remoto\"",
    "Search users" : "Cerca utenti",
    "You might not have have permissions to view it, ask the sender to share it" : "Potresti non avere i permessi per visualizzarlo, chiedi al mittente di condividerlo",
    "Set up templates folder" : "Configura la cartella dei modelli",
    "Toggle %1$s sublist" : "Passa alla sottolista %1$s",
    "Toggle grid view" : "Commuta la vista a griglia",
    "Deleted files" : "File eliminati",
    "Shares" : "Condivisioni",
    "Shared with others" : "Condivisi con altri",
    "Shared with you" : "Condivisi con te",
    "Deleted shares" : "Condivisioni eliminate",
    "Pending shares" : "Condivisioni in corso",
    "This file has the tag {tag}" : "Questo file ha il tag {tag}",
    "This file has the tags {firstTags} and {lastTag}" : "Il file ha le etichette {firstTags} e {lastTag}",
    "Select the row for {displayName}" : "Seleziona la riga per {displayName}",
    "Open folder {name}" : "Apri la cartella {name}",
    "Unselect all" : "Deseleziona tutto",
    "ascending" : "crescente",
    "descending" : "decrescente",
    "Sort list by {column} ({direction})" : "Ordina la lista per {column} ({direction})",
    "This list is not fully rendered for performances reasons. The files will be rendered as you navigate through the list." : "Questo elenco non è stata mostrato completamente per ragioni di prestazioni. I file saranno mostrati durante la navigazione dell'elenco.",
    "Search for an account" : "Cerca un account",
    "Choose" : "Scegli",
    "No files or folders have been deleted yet" : "Nessun file o cartella è stato ancora eliminato",
    "Add" : "Aggiungi",
    "The files is locked" : "Il file è bloccato"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
